@@ -4,6 +4,7 @@
 #include "Core/Str.h"
 #include "Core/StrBuf.h"
 #include "Core/Convert.h"
+#include "Core/Exception.h"
 
 namespace storm {
 
@@ -40,6 +41,10 @@ namespace storm {
 		}
 	}
 
+	void Buffer::throwOutOfBounds(Nat id) const {
+		throw new (runtime::someEngine()) ArrayError(id, count());
+	}
+
 	Buffer buffer(EnginePtr e, Nat count) {
 		return Buffer(runtime::allocBuffer(e.v, count));
 	}
